#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-1Tjc5J30sX4JnjzbhefQN1
key:                  coinbase-pro-0.9.3.2-1Tjc5J30sX4JnjzbhefQN1
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  5820b13e7ac4faf18e50f093985848e8
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-1Tjc5J30sX4JnjzbhefQN1
depends:
    HsOpenSSL-0.11.7.10-96vqWLLGvzWCsJBStwAHQg
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    aeson-casing-0.2.0.0-1eM94DTQdPHjOlcW5D5OE
    async-2.2.6-Cc2ylPSJ9T994nMR0Eaxyq base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-1zIyUWM4Y5m2xcUOCgTnmO exceptions-0.10.7
    http-api-data-0.6.1-BwFpbURgyw753i0oz3R4fv
    http-client-0.7.19-uRvF7eEYhRDNuWEwLS8eA
    http-client-tls-0.3.6.4-2mFFKjIM8FK6v9pBPz2NDG
    http-streams-0.8.9.9-7BR7NBIqU9YJTCfppOQUI4
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    io-streams-1.5.2.2-2oP12mPDnfE6u1eNabqvym
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    servant-0.20.3.0-2pYqMzj0m6xGncNpoY3BN0
    servant-client-0.20.3.0-Ln6v4DSTqV3NsHbqybYKL
    servant-client-core-0.20.3.0-An4HVTbmXWI4QSGlY3rU2x
    tasty-1.5.3-9Ly5zOHTOKj1qAbC4RsUQH
    tasty-hunit-0.10.2-3kdvFGfzvwIBwJXgxUelSp text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-E7Ify97Dkap4eStUuiLlZO
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    uuid-1.3.16.1-JVmLTsI5TbjGEwOHOC97Bp
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    websockets-0.12.7.3-4SLjGUZ111D4LJt0jBPmBy
    wuss-2.0.1.7-46BwBaKms9oFQCXxXQMbqm

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

